@@ -22,6 +22,7 @@
 #' (FALSE).
 #' @param overwrite Whether to overwrite previously existing table with name
 #' same.
+#' @param logPrefix Prefix to use when saving a log file.
 #' @param ... For compatibility (not used).
 #'
 #' @return Reference to a table in the cdm
@@ -32,6 +33,7 @@ compute.cdm_table <- function(x,
                               name = NULL,
                               temporary = NULL,
                               overwrite = TRUE,
+                              logPrefix = NULL,
                               ...) {
   if (is.character(name) & is.null(temporary)) temporary <- FALSE
   if (is.null(name)) name <- uniqueTableName()
@@ -40,23 +42,53 @@ compute.cdm_table <- function(x,
   cl <- class(src)[class(src) != "cdm_source"]
   cx <- class(x)
 
-  logFile <- getOption("omopgenerics.log_sql_path")
-  if(!is.null(logFile) && inherits(cdmSource(x), "db_cdm")){
+  logSqlFile <- getOption("omopgenerics.log_sql_path")
+  if (!is.null(logSqlFile) && inherits(cdmSource(x), "db_cdm")) {
     # log sql if option set
     # must have specified a directory that exists
-    if (dir.exists(logFile)) {
-    cli::cli_inform("SQL query saved to {logFile}")
-    writeLines(utils::capture.output(dplyr::show_query(x)),
-               here::here(logFile,
-                          paste0("logged_query_ran_on_",
-                          format(Sys.time(),
-                                 format = "%Y_%m_%d_at_%H_%M_%S"),
-                          ".sql"
-                          )))
+    if (dir.exists(logSqlFile)) {
+      cli::cli_inform("SQL query saved to {logSqlFile}")
+      writeLines(
+        utils::capture.output(dplyr::show_query(x)),
+        here::here(
+          logSqlFile,
+          paste0(
+            logPrefix, "logged_query_ran_on_",
+            format(Sys.time(),
+              format = "%Y_%m_%d_at_%H_%M_%S"
+            ),
+            ".sql"
+          )
+        )
+      )
     } else {
-      cli::cli_inform("SQL query not saved as '{logFile}' not an existing directory")
+      cli::cli_inform("SQL query not saved as '{logSqlFile}' not an existing directory")
     }
+  }
+
+  logSqlExplainFile <- getOption("omopgenerics.log_sql_explain_path")
+  if (!is.null(logSqlExplainFile) && inherits(cdmSource(x), "db_cdm")) {
+    # log sql if option set
+    # must have specified a directory that exists
+    if (dir.exists(logSqlExplainFile)) {
+      cli::cli_inform("SQL explain saved to {logSqlExplainFile}")
+      writeLines(
+        utils::capture.output(dplyr::explain(x)),
+        here::here(
+          logSqlExplainFile,
+          paste0(
+            logPrefix, "logged_query_ran_on_",
+            format(Sys.time(),
+              format = "%Y_%m_%d_at_%H_%M_%S"
+            ),
+            ".sql"
+          )
+        )
+      )
+    } else {
+      cli::cli_inform("SQL explain not saved as '{logSqlExplainFile}' not an existing directory")
     }
+  }
 
   res <- x |>
     keepClass() |>
@@ -108,4 +140,3 @@ tmpPrefix <- function() {
   options(tmp_prefix_number = i)
   sprintf("tmp_%03i_", i)
 }
-
