@@ -29,11 +29,10 @@ exportSummarisedResult <- function(...,
                                    fileName = "results_{cdm_name}_{date}.csv",
                                    path = getwd()) {
   # initial checks
-  results <- list(...)
-  assertList(x = results, class = "summarised_result")
+  results <- list(...) |>
+    purrr::compact()
   assertCharacter(fileName, length = 1, minNumCharacter = 1)
   assertCharacter(path, length = 1, minNumCharacter = 1)
-
   if (dirname(fileName) != ".") {
     path <- dirname(fileName)
     fileName <- basename(fileName)
@@ -50,9 +49,16 @@ exportSummarisedResult <- function(...,
     fileName <- paste0(tools::file_path_sans_ext(fileName), ".csv")
   }
 
-  # bind and suppress
-  results <- bind(...) |> suppress(minCellCount = minCellCount)
+  # if result is list(), results will be a list containing an empty list
+  if (length(results) == 0) {
+    cli::cli_warn("Input is NULL, empty result exported.")
+    results <- emptySummarisedResult()
+  } else {
+    results <- bind(results)
+  }
+  assertClass(results, "summarised_result")
 
+  results <- suppress(results, minCellCount = minCellCount)
   # cdm name
   cdmName <- results$cdm_name |>
     unique() |>
@@ -62,7 +68,6 @@ exportSummarisedResult <- function(...,
     pattern = "\\{cdm_name\\}",
     replacement = cdmName
   )
-
   # date
   date <- format(Sys.Date(), format = "%Y_%m_%d") |> as.character()
   fileName <- stringr::str_replace(
@@ -85,7 +90,7 @@ exportSummarisedResult <- function(...,
 pivotSettings <- function(x) {
   x |>
     settings() |>
-    dplyr::mutate(dplyr::across(!"result_id", ~ as.character(.x))) |>
+    dplyr::mutate(dplyr::across(!"result_id", \(x) as.character(x))) |>
     tidyr::pivot_longer(
       cols = !"result_id",
       names_to = "estimate_name",
